@@ -181,11 +181,11 @@ class Field(object):
     """Class that encapsulates access to field data.
 
     :param name: Name of the field
-    :param data: 2D, 3D or 4D array of field data
-    :param lon: Longitude coordinates of the field. (only if grid is None)
-    :param lat: Latitude coordinates of the field. (only if grid is None)
-    :param depth: Depth coordinates of the field. (only if grid is None)
-    :param time: Time coordinates of the field. (only if grid is None)
+    :param data: 2D, 3D or 4D numpy array of field data
+    :param lon: Longitude coordinates (numpy vector or array) of the field (only if grid is None)
+    :param lat: Latitude coordinates (numpy vector or array) of the field (only if grid is None)
+    :param depth: Depth coordinates (numpy vector or array) of the field (only if grid is None)
+    :param time: Time coordinates (numpy vector) of the field (only if grid is None)
     :param mesh: String indicating the type of mesh coordinates and
            units used during velocity interpolation: (only if grid is None)
 
@@ -193,15 +193,14 @@ class Field(object):
               correction for zonal velocity U near the poles.
            2. flat: No conversion, lat/lon are assumed to be in m.
     :param grid: :class:`parcels.grid.Grid` object containing all the lon, lat depth, time
-           mesh and time_origin information
+           mesh and time_origin information. Can be constructed from any of the Grid objects
     :param transpose: Transpose data to required (lon, lat) layout
-    :param vmin: Minimum allowed value on the field.
-           Data below this value are set to zero
-    :param vmax: Maximum allowed value on the field
-           Data above this value are set to zero
-    :param time_origin: Time origin of the time axis (only if grid is None)
-    :param interp_method: Method for interpolation
-    :param allow_time_extrapolation: boolean whether to allow for extrapolation
+    :param vmin: Minimum allowed value on the field. Data below this value are set to zero
+    :param vmax: Maximum allowed value on the field. Data above this value are set to zero
+    :param time_origin: Time origin (datetime object) of the time axis (only if grid is None)
+    :param interp_method: Method for interpolation. Either 'linear' or 'nearest'
+    :param allow_time_extrapolation: boolean whether to allow for extrapolation in time
+           (i.e. beyond the last available time snapshot)
     :param time_periodic: boolean whether to loop periodically over the time component of the Field
            This flag overrides the allow_time_interpolation and sets it to False
     """
@@ -220,7 +219,7 @@ class Field(object):
         if grid:
             self.grid = grid
         else:
-            self.grid = RectilinearZGrid('auto_gen_grid', lon, lat, depth, time, time_origin=time_origin, mesh=mesh)
+            self.grid = RectilinearZGrid(lon, lat, depth, time, time_origin=time_origin, mesh=mesh)
         # self.lon, self.lat, self.depth and self.time are not used anymore in parcels.
         # self.grid should be used instead.
         # Those variables are still defined for backwards compatibility with users codes.
@@ -277,10 +276,13 @@ class Field(object):
         """Create field from netCDF file
 
         :param name: Name of the field to create
-        :param dimensions: Variable names for the relevant dimensions
-        :param filenames: Filenames of the field
-        :param indices: indices for each dimension to read from file
-        :param allow_time_extrapolation: boolean whether to allow for extrapolation
+        :param dimensions: Dictionary mapping variable names for the relevant dimensions in the NetCDF file
+        :param filenames: list of filenames to read for the field.
+               Note that wildcards ('*') are also allowed
+        :param indices: dictionary mapping indices for each dimension to read from file.
+               This can be used for reading in only a subregion of the NetCDF file
+        :param allow_time_extrapolation: boolean whether to allow for extrapolation in time
+               (i.e. beyond the last available time snapshot
         :param mesh: String indicating the type of mesh coordinates and
                units used during velocity interpolation:
 
@@ -365,14 +367,14 @@ class Field(object):
             time[0] = 0
         if len(lon.shape) == 1:
             if len(depth.shape) == 1:
-                grid = RectilinearZGrid('auto_gen_grid', lon, lat, depth, time, time_origin=time_origin, mesh=mesh)
+                grid = RectilinearZGrid(lon, lat, depth, time, time_origin=time_origin, mesh=mesh)
             else:
-                grid = RectilinearSGrid('auto_gen_grid', lon, lat, depth, time, time_origin=time_origin, mesh=mesh)
+                grid = RectilinearSGrid(lon, lat, depth, time, time_origin=time_origin, mesh=mesh)
         else:
             if len(depth.shape) == 1:
-                grid = CurvilinearZGrid('auto_gen_grid', lon, lat, depth, time, time_origin=time_origin, mesh=mesh)
+                grid = CurvilinearZGrid(lon, lat, depth, time, time_origin=time_origin, mesh=mesh)
             else:
-                grid = CurvilinearSGrid('auto_gen_grid', lon, lat, depth, time, time_origin=time_origin, mesh=mesh)
+                grid = CurvilinearSGrid(lon, lat, depth, time, time_origin=time_origin, mesh=mesh)
         if name in ['cosU', 'sinU', 'cosV', 'sinV']:
             allow_time_extrapolation = True
         return cls(name, data, grid=grid,
@@ -526,7 +528,6 @@ class Field(object):
         return xi
 
     def search_indices_rectilinear(self, x, y, z, tidx=-1, time=-1):
-
         grid = self.grid
         xi = yi = -1
         lon_index = grid.lon <= x
@@ -799,9 +800,9 @@ class Field(object):
             for i, g in enumerate(gridset.grids):
                 if min(uiGrid, viGrid) > -1:
                     break
-                if g.name == self.fieldset.U.grid.name:
+                if g is self.fieldset.U.grid:
                     uiGrid = i
-                if g.name == self.fieldset.V.grid.name:
+                if g is self.fieldset.V.grid:
                     viGrid = i
             return "temporal_interpolationUV(%s, %s, %s, %s, U, V, particle->CGridIndexSet, %s, %s, &%s, &%s, %s)" \
                 % (x, y, z, t,
@@ -814,17 +815,17 @@ class Field(object):
             for i, g in enumerate(gridset.grids):
                 if min(uiGrid, viGrid, cosuiGrid, sinuiGrid, cosviGrid, sinviGrid) > -1:
                     break
-                if g.name == self.fieldset.U.grid.name:
+                if g is self.fieldset.U.grid:
                     uiGrid = i
-                if g.name == self.fieldset.V.grid.name:
+                if g is self.fieldset.V.grid:
                     viGrid = i
-                if g.name == self.fieldset.cosU.grid.name:
+                if g is self.fieldset.cosU.grid:
                     cosuiGrid = i
-                if g.name == self.fieldset.sinU.grid.name:
+                if g is self.fieldset.sinU.grid:
                     sinuiGrid = i
-                if g.name == self.fieldset.cosV.grid.name:
+                if g is self.fieldset.cosV.grid:
                     cosviGrid = i
-                if g.name == self.fieldset.sinV.grid.name:
+                if g is self.fieldset.sinV.grid:
                     sinviGrid = i
             return "temporal_interpolationUVrotation(%s, %s, %s, %s, U, V, cosU, sinU, cosV, sinV, particle->CGridIndexSet, %s, %s, %s, %s, %s, %s, &%s, &%s, %s)" \
                 % (x, y, z, t,
@@ -836,7 +837,7 @@ class Field(object):
         gridset = self.fieldset.gridset
         iGrid = -1
         for i, g in enumerate(gridset.grids):
-            if g.name == self.grid.name:
+            if g is self.grid:
                 iGrid = i
                 break
         return "temporal_interpolation(%s, %s, %s, %s, %s, %s, %s, &%s, %s)" \
@@ -985,8 +986,6 @@ class Field(object):
         dset.to_netcdf(filepath)
 
     def advancetime(self, field_new, advanceForward):
-        if self.name == 'UV':
-            return
         if advanceForward == 1:  # forward in time, so appending at end
             self.data = np.concatenate((self.data[1:, :, :], field_new.data[:, :, :]), 0)
             self.time = self.grid.time
